@@ -1,12 +1,12 @@
 package File::Move::Undoable;
 
-our $DATE = '2014-12-05'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Builtin::Logged qw(system);
 use File::MoreUtil qw(file_exists l_abs_path);
@@ -176,15 +176,31 @@ File::Move::Undoable - Move file/directory using rename/rsync, with undo support
 
 =head1 VERSION
 
-This document describes version 0.04 of File::Move::Undoable (from Perl distribution File-Move-Undoable), released on 2014-12-05.
+This document describes version 0.05 of File::Move::Undoable (from Perl distribution File-Move-Undoable), released on 2015-08-17.
+
+=head1 FAQ
+
+=head2 Why do you use rsync? Why not, say, File::Copy::Recursive?
+
+With C<rsync>, we can continue interrupted transfer. We need this ability for
+recovery. Also, C<rsync> can handle hardlinks and preservation of ownership,
+something which L<File::Copy::Recursive> currently does not do. And, being
+implemented in C, it might be faster when processing large files/trees.
+
+=head1 SEE ALSO
+
+L<Setup>
+
+L<Rinci::Transaction>
 
 =head1 FUNCTIONS
 
 
 =head2 mv(%args) -> [status, msg, result, meta]
 
-Move file/directory using rename/rsync, with undo support.
+{en_US Move file/directory using rename/rsync, with undo support}.
 
+{en_US 
 If moving to the same filesystem, will move using C<rename()>. On undo will
 restore the old name.
 
@@ -200,6 +216,7 @@ Fixable state: C<source> exists and C<target> doesn't exist.
 Unfixable state: C<source> does not exist, or both C<source> and C<target> exist
 (unless we are moving to a different filesystem, in which it means an
 interrupted transfer and thus fixable).
+}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -208,23 +225,27 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<rsync_opts> => I<array> (default: ["-a"])
+=item * B<rsync_opts> => I<array[str]> (default: ["-a"])
 
-Rsync options.
+{en_US Rsync options}.
 
+{en_US 
 By default, C<-a> is used. You should not use rsync options that modify or
 destroy source, like C<--remove-source-files> as it will make recovery of
 interrupted move impossible.
+}
 
 =item * B<source>* => I<str>
 
 =item * B<target>* => I<str>
 
-Target location.
+{en_US Target location}.
 
+{en_US 
 Note that to avoid ambiguity, you must specify full location instead of just
 directory name. For example: mv(source=>'/dir', target=>'/a') will move /dir to
 /a and mv(source=>'/dir', target=>'/a/dir') will move /dir to /a/dir.
+}
 
 =back
 
@@ -254,8 +275,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -265,22 +284,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
-=head1 FAQ
-
-=head2 Why do you use rsync? Why not, say, File::Copy::Recursive?
-
-With C<rsync>, we can continue interrupted transfer. We need this ability for
-recovery. Also, C<rsync> can handle hardlinks and preservation of ownership,
-something which L<File::Copy::Recursive> currently does not do. And, being
-implemented in C, it might be faster when processing large files/trees.
-
-=head1 SEE ALSO
-
-L<Setup>
-
-L<Rinci::Transaction>
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -288,7 +292,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/File-Move-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-File-Move-Undoable>.
+Source repository is at L<https://github.com/sharyanto/perl-File-Move-Undoable>.
 
 =head1 BUGS
 
@@ -304,7 +308,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
